@@ -49,7 +49,9 @@ class EBSVolumeHasSSERule(Rule):
         result = Result()
         for logical_id, resource in cfmodel.Resources.items():
             if resource.Type == "AWS::EC2::Volume":
-                if resource.Properties.get("Encrypted") != "true":
+                encrypted_status = getattr(resource.Properties, "Encrypted", None)
+
+                if encrypted_status is None or encrypted_status.lower() != "true":
                     self.add_failure_to_result(
                         result,
                         self.REASON.format(logical_id),
